==> lava-test-0.3.3.tar.gz: lava-test-0.3.3/lava_test/test_definitions/xrestop.py <==
# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
xrestop - test for X11 server resource usage monitor
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

Default options:
 None
"""

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

INSTALLSTEPS = ['bzr branch lp:~linaro-foundations/lava-test/xrestopscript']
RUNSTEPS = ["./xrestopscript/xrestop.sh $(OPTIONS)"]
PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+)"
DEFAULT_OPTIONS = ""

xrestopinst = TestInstaller(INSTALLSTEPS, deps=["xrestop"])
xrestoprun = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
xrestopparser = TestParser(PATTERN,
                   appendall={'units':'KB', 'result':'pass'})
testobj = Test(test_id="xrestop", installer=xrestopinst,
                                  runner=xrestoprun, parser=xrestopparser)

==> lava-test-0.13.tar.gz: lava-test-0.13/lava_test/test_definitions/xrestop.py <==
# Copyright (c) 2010, 2011 Linaro
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""
xrestop - test for X11 server resource usage monitor

**URL:** http://code.launchpad.net/~linaro-foundations/lava-test/xrestopscript

**Default options:** None
"""

from lava_test.core.installers import TestInstaller
from lava_test.core.parsers import TestParser
from lava_test.core.runners import TestRunner
from lava_test.core.tests import Test

BZR_REPOS = ['lp:~linaro-foundations/lava-test/xrestopscript']
RUNSTEPS = ["./xrestopscript/xrestop.sh $(OPTIONS)"]
PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+)"
DEFAULT_OPTIONS = ""

installer = TestInstaller(deps=["xrestop"], bzr_repos=BZR_REPOS)
runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
parser = TestParser(PATTERN, appendall={'units': 'KB', 'result': 'pass'})

testobj = Test(
    test_id="xrestop",
    installer=installer,
    runner=runner,
    parser=parser)
